@@ -1,6 +1,6 @@
 """
-toolchest_client.exceptions
-~~~~~~~~~~~~~~~~~~~~~~~~~~~
+toolchest_client.api.exceptions
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 This module contains custom exceptions used for the Toolchest client.
 """
@@ -12,6 +12,10 @@ class ToolchestException(OSError):
     """
 
 
+class ToolchestKeyError(ToolchestException):
+    """Invalid Toolchest auth key."""
+
+
 class DataLimitError(ToolchestException):
     """Data limit for Toolchest exceeded."""
 
