@@ -32,7 +32,26 @@ class Kraken2(Tool):
             output_is_directory=True,
         )
 
-    def _sanity_output_check(self):
+    def _preflight(self):
+        """Kraken 2 specific preflight"""
+        super()._preflight()
+
+        if os.path.exists(self.output_path):
+            if os.path.isfile(self.output_path):
+                raise ValueError(
+                    f"{self.output_path} is a file. Please pass a directory instead of an output file."
+                )
+        else:
+            os.makedirs(self.output_path)
+
+        for file_path in ["kraken2_output.txt", "kraken2_report.txt", "output", "output.tar.gz"]:
+            joined_file_path = os.path.join(self.output_path, file_path)
+            if os.path.exists(joined_file_path):
+                print(f"WARNING: {joined_file_path} already exists and will be overwritten")
+
+    def _postflight(self):
+        """Kraken 2 specific postflight"""
+        # Do a basic sanity check on the output files
         for output_name in ["kraken2_output.txt", "kraken2_report.txt"]:
             output_file_path = f"{self.output_path}/{output_name}"
             assert_exists(output_file_path, must_be_file=True)
